@@ -19,7 +19,7 @@ class Storage:
 
 	@property
 	def var1(self) -> Type[SyncedVariable]:
-		if self.__var1 is not None:
+		if self.__var1 is None:
 			self.__var1 = SyncedDict(self.__document.sheet1)
 		return self.__var1
 		
